@@ -12,7 +12,8 @@ def command_init(log: Logger, path: Path):
     if (path / NumerousRepository.FILE_NAME).exists():
         try:
             repo = NumerousRepository(path).load()
-            print(red(f'Cannot init: Folder already a repository for {bold(repo.remote.name)}'))
+            print(red('Cannot init: Folder already a repository for '
+                      + bold(repo.remote.name)))  # type: ignore[union-attr]
         except Exception:
             print(red('Cannot init: Folder already exists, but repository configuration is invalid'))
         finally:
