@@ -2,18 +2,18 @@ import sys
 from datetime import datetime
 from logging import Logger
 from pathlib import Path
+from typing import List
 
-import grpc
 from dirtools import Dir, filehash
 from prettytable import PrettyTable
-from spm_pb2 import HistoryRequest, HistoryUpdate
 
-from ..auth import AuthenticationError, TokenAuth, login
+from ..auth import AuthenticationError, login
+from ..build_manager_client import HistoryUpdate, get_build_manager_client
 from ..repository import NumerousRepository
-from ..utils import bold, cyan, get_build_manager, green, red, yellow
+from ..utils import bold, cyan, green, red, yellow
 
 
-def print_updates_table(repo: NumerousRepository, updates: list[HistoryUpdate]):
+def print_updates_table(repo: NumerousRepository, updates: List[HistoryUpdate]):
     dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
     table = PrettyTable()
     table.field_names = ["Timestamp", "Scenario", "Comment", "Commit ID", "Current"]
@@ -22,19 +22,19 @@ def print_updates_table(repo: NumerousRepository, updates: list[HistoryUpdate]):
             datetime.fromtimestamp(update.timestamp),
             update.scenario_id,
             update.comment,
-            update.id,
-            f"{green('*')} {red('dirty') if dirty else ''}" if repo.commit == update.id else ""])
+            update.commit_id,
+            f"{green('*')} {red('dirty') if dirty else ''}" if repo.commit == update.commit_id else ""])
     print(table)
 
 
-def print_updates_git(repo: NumerousRepository, updates: list[HistoryUpdate]):
+def print_updates_git(repo: NumerousRepository, updates: List[HistoryUpdate]):
     dirty = Dir(str(repo.path)).hash(index_func=filehash) != repo.snapshot
     for update in updates:
-        state = f" {green('current')}{red(' dirty') if dirty else ''}" if repo.commit == update.id else ""
-        print(f"{yellow(f'commit {update.id}')} {yellow('(')}{cyan(update.project_id + ':' + update.scenario_id)}"
-              f"{yellow(')')}{state}")
+        state = f" {green('current')}{red(' dirty') if dirty else ''}" if repo.commit == update.commit_id else ""
+        print(f"{yellow(f'commit {update.commit_id}')} {yellow('(')}"
+              f"{cyan(update.project_id + ':' + update.scenario_id)}{yellow(')')}{state}")
         update_time = datetime.fromtimestamp(update.timestamp)
-        print(f"Author: {update.user.full_name} <{update.user.email}>")
+        print(f"Author: {update.user_full_name} <{update.user_email}>")
         print(f'Date:   {update_time.strftime("%a %b %d %H:%M:%S %Y %z")}')
         print()
         for line in update.comment.splitlines():
@@ -65,20 +65,18 @@ def command_log(log: Logger, path: Path, display_mode: str):
         sys.exit(1)
 
     try:
-        access_token = login(repo)
+        id_token = login(repo)
     except AuthenticationError:
         print(red("Cannot get logs: Login failed."))
         sys.exit(1)
-    call_credentials = grpc.metadata_call_credentials(TokenAuth(access_token))
 
-    with get_build_manager(repo.remote.api_url) as build_manager:
-        history_request = HistoryRequest(repository=repo.remote.name, scenario_id=repo.scenario.id)
-        history_reply, _call = build_manager.GetHistory.with_call(history_request, credentials=call_credentials)
+    with get_build_manager_client(repo.remote.api_url, id_token) as build_manager:
+        updates = build_manager.get_scenario_history(repo.remote.name, repo.scenario.id)
 
-    if not history_reply.updates:
+    if not updates:
         print(f"No history exists for remote {bold(repo.remote)}")
 
     if display_mode == 'table':
-        print_updates_table(repo, history_reply.updates)
+        print_updates_table(repo, updates)
     else:
-        print_updates_git(repo, history_reply.updates)
+        print_updates_git(repo, updates)
