@@ -1,4 +1,5 @@
 import logging
+import sys
 from argparse import ArgumentParser, Namespace
 from pathlib import Path
 
@@ -7,7 +8,7 @@ from .repository import ProjectScenario, RepositoryRemote
 from .utils import log, red
 
 
-def parse_arguments():
+def parse_arguments(args: list[str]):
     parser = ArgumentParser(description='Push and pull image context to and from numerous workspace.', prog="numerous")
     parser.add_argument('-v', dest="verbose", action='store_true', help="Verbose mode. Prints informational messages.")
     parser.add_argument('-vv', dest="extra_verbose", action='store_true',
@@ -58,7 +59,7 @@ def parse_arguments():
 
     command_parsers.add_parser("version", help="Get the current version number of this tool.")
 
-    return parser.parse_args()
+    return parser.parse_args(args)
 
 
 def path_or_none(path: str):
@@ -103,5 +104,5 @@ def run_command(ns: Namespace):
 
 
 def main():
-    ns = parse_arguments()
+    ns = parse_arguments(sys.argv[1:])
     run_command(ns)
